<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../src/clipboard.cpp" line="79"/>
        <source>Copy color %1 to clipboard</source>
        <translation>Color copiado %1 al portapapeles </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main.cpp" line="47"/>
        <source>Deepin Picker is a fast screen color picking tool. RGB and HEX code can be obtained according color picked and auto saved to clipboard. The color picking area is where mouse clicked.</source>
        <translation>El selector deepin es una herramienta de selección de color en pantalla. El código RGB y HEX se  obtiene de acuerdo al color elegido y se guarda automáticamente en el portapapeles. El área de selección de color es donde debe hacer clic con el ratón.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="69"/>
        <source>Deepin Picker</source>
        <translation>Selector Deepin</translation>
    </message>
</context>
</TS>